**Simple PLOTs, Contours and Histograms** is a small package with wrapper functions designed to simplify plotting calls from matplotlib.

[![Github release](https://img.shields.io/github/release/MBravoS/splotch.svg?label=tag&colorB=54ebff)](https://github.com/MBravoS/splotch/releases) [![PyPI version](https://img.shields.io/pypi/v/splotch.svg?colorB=ff0080)](https://pypi.python.org/pypi/splotch)

<p align="center">
<img src="/example_images/SPLOTCH_logo.png" alt="drawing" width="500"/>
</p>

 Histograms                 | Scatter Plots
:---:|:---:
| <img src="/example_images/example_hist.png" alt="drawing" width="400"/> |  <img src="/example_images/example_scatter.png" alt="drawing" width="400"/>

 Contour Plots              | Sector Plots             
:---:|:---:
| <img src="/example_images/example_contours.png" alt="drawing" width="400"/> | <img src="/example_images/example_sectorplot.png" alt="drawing" width="400"/>

| Corner Plots              | Subplots                
:---:|:---:
| <img src="/example_images/example_cornerplot.png" alt="drawing" width="400"/>  |  <img src="/example_images/example_subplots.png" alt="drawing" width="400"/>


The package is available in for installation using `>pip install splotch`, though you may get the lastest stable version using `>pip install git+https://github.com/MBravoS/splotch.git@master`, or the latest development version using `>pip install git+https://github.com/MBravoS/splotch.git@devel`.

The documentation is [splotch's readthedocs page](https://splotch.readthedocs.io/en/latest/).

*Planned releases*:
* Addition of legend customisation function (0.7.0.0).
* Re-work for PEP coding style compliance (using PyLint) (0.8.0.0).
* Add basic tests with Travis (0.9.0.0).
* Improved documentation and first version release (1.0.0.0).
